summaryrefslogtreecommitdiff
path: root/sites
diff options
context:
space:
mode:
authorDries Buytaert <dries@buytaert.net>2005-03-12 10:51:32 +0000
committerDries Buytaert <dries@buytaert.net>2005-03-12 10:51:32 +0000
commita666c7da9e6ab1d0c2f73ed5bd6b7245c47e81e6 (patch)
tree76c14f6c6bda8f7aa8825510b0060dbe6c1088fd /sites
parent2eec4e806f83040fe7f40f4bbf79401d45a8d108 (diff)
downloadbrdo-a666c7da9e6ab1d0c2f73ed5bd6b7245c47e81e6.tar.gz
brdo-a666c7da9e6ab1d0c2f73ed5bd6b7245c47e81e6.tar.bz2
- Patch #18641 by Morbus:
# The INSTALL.txt no longer contains the SERVER CONFIGURATION block. These settings are now hardcoded into sites/default/settings.php, and are merely scary technical junk here. # The INSTALL.txt has been updated with the latest system requirements. A whole sentence was struck regarding differing versions of PHP for the OSs. # The INSTALL.txt contains URLs to MySQL and PostgreSQL. If we're including the URL for PHP in the same sentence, then there's no reason why we wouldn't include them for the database engines. What are the minimal requirements for the RDBMS? Those should be included here too. # The INSTALL.txt's OPTIONAL COMPONENTS has renamed to OPTIONAL REQUIREMENTS. The only difference between the meaning is the amount of user confusion. # The INSTALL.txt has a new CONTENTS OF THIS FILE, in hopes that people will more immediately notice that there are upgrade instructions at the bottom. # The INSTALL.txt had some potentially confusing lines adjusted, including further clarifications, standarding to "userid" (instead of using both userid and username interchangebly) and so on. # I've moved most of .htaccess php_value's to the ini_set system for /sites/. There are a few reasons for this, chiefly that it is centralizing all the PHP setting modifications to one place. But, this also clears up a few initial configuration issues: first, the user doesn't have to worry about whether they have Apache 1 or 2, and whether they need to change an IfModule line. Also, the running assumption is that these php_value's are /going to work by default anyways/, when the INSTALL.txt suggests otherwise (under OPTIONAL REQUIREMENTS, it talks about "the ability to use local .htaccess files", which suggests that "local .htaccess files" INCLUDING "mod_rewrite" are entirely optional.) Some variables, however, had to remain in .htaccess because they can't be overridden at runtime, but the amount was so small that duplicating them for both Apache 1 and Apache 2 possibilities is no longer a prohibitive concern. # There are two variables in .htaccess that I'm concerned about: track_vars, and allow_call_time_pass_reference. track_vars appears to be no longer necessary (as of 4.0.3, track_vars is always on, and my setting it here had no impact on the results of a phpinfo), and allow_call_time_pass_reference seems, at least here, to ONLY WORK if the .htaccess value is set to "1", and not "On" - meaning that Drupal installations are currently working correctly with its default value (off). According to the PHP docs, this feature is now deprecated. However, since both of these variables require further investigation, track_vars has been moved to settings.php, and allow_call_time_pass_reference has been "fixed" to a 1 (not 'On'). # Along with the changes above for sites/default/settings.php, I've also removed the spacing indent in the documentation, as well as many a few grammatical/punctuation changes here and there. I don't think the leading spacing is "right" according to the style guidelines, but maybe there's a special need for it. Correct me if I'm wrong.
Diffstat (limited to 'sites')
-rw-r--r--sites/default/settings.php91
1 files changed, 48 insertions, 43 deletions
diff --git a/sites/default/settings.php b/sites/default/settings.php
index b39c9ea32..677b6ad6c 100644
--- a/sites/default/settings.php
+++ b/sites/default/settings.php
@@ -5,18 +5,17 @@
* @file
* Drupal site-specific configuration file.
*
- * The configuration file which will be loaded is based upon the rules
- * below.
+ * The configuration file to be loaded is based upon the rules below.
*
* The configuration directory will be discovered by stripping the
* website's hostname from left to right and pathname from right to
- * left. The first configuration file found will be used and any
- * others will be ignored. If no other configuration file is found
+ * left. The first configuration file found will be used and any
+ * others will be ignored. If no other configuration file is found
* then the default configuration file at 'sites/default' will be used.
*
- * Example for a ficticious site installed at
- * http://www.drupal.org/mysite/test/ the 'settings.php' is
- * searched in the following directories:
+ * For example, for a ficticious site installed at
+ * http://www.drupal.org/mysite/test/, the 'settings.php'
+ * is searched in the following directories:
*
* 1. sites/www.drupal.org.mysite.test
* 2. sites/drupal.org.mysite.test
@@ -36,27 +35,27 @@
/**
* Database settings:
*
- * Note that the $db_url variable gets parsed using PHP's built-in
- * URL parser (i.e. using the "parse_url()" function) so make sure
- * not to confuse the parser. In practice, you should avoid using
- * special characters that are not used in "normal" URLs either.
- * That is, the use of ':', '/', '@', '?', '=' and '#', ''', '"',
- * and so on is likely to confuse the parser; use alpha-numerical
- * characters instead.
+ * Note that the $db_url variable gets parsed using PHP's built-in
+ * URL parser (i.e. using the "parse_url()" function) so make sure
+ * not to confuse the parser. In practice, you should avoid using
+ * special characters that are not used in "normal" URLs either.
+ * That is, the use of ':', '/', '@', '?', '=' and '#', ''', '"',
+ * and so on is likely to confuse the parser; use alpha-numerical
+ * characters instead.
*
- * To specify multiple connections to be used in your site (i.e. for
- * complex custom modules) you can also specify an associative array
- * of $db_url variables with the 'default' element used until otherwise
- * requested.
+ * To specify multiple connections to be used in your site (i.e. for
+ * complex custom modules) you can also specify an associative array
+ * of $db_url variables with the 'default' element used until otherwise
+ * requested.
*
- * If an optional $db_prefix is specified all database table names
- * will be prepended with this string. Be sure to use valid database
- * characters only, usually alphanumeric and underscore. If no
- * prefixes are desired, set to empty string "".
+ * If an optional $db_prefix is specified, all database table names
+ * will be prepended with this string. Be sure to use valid database
+ * characters only, usually alphanumeric and underscore. If no
+ * prefixes are desired, set to empty string ''.
*
- * Database URL format:
- * $db_url = 'mysql://db_user:db_password@db_hostname/db_name';
- * $db_url = 'pgsql://db_user:db_password@db_hostname/db_name';
+ * Database URL format:
+ * $db_url = 'mysql://db_user:db_password@db_hostname/db_name';
+ * $db_url = 'pgsql://db_user:db_password@db_hostname/db_name';
*/
$db_url = 'mysql://drupal:drupal@localhost/drupal';
$db_prefix = '';
@@ -64,41 +63,47 @@ $db_prefix = '';
/**
* Base URL:
*
- * The URL of your website's main page. It is not allowed to have
- * a trailing slash; Drupal will add it for you.
+ * The URL of your website's main page. It is not allowed to have
+ * a trailing slash; Drupal will add it for you.
*/
$base_url = 'http://localhost';
/**
* PHP settings:
*
* To see what PHP settings are known to work well, read the PHP
* documentation at http://www.php.net/manual/en/ini.php#ini.list
* and take a look at the .htaccess file to see which settings are
* used there. Settings defined here should not be duplicated there
* to avoid conflict issues.
*/
+ini_set('arg_separator.output', '&amp;');
+ini_set('magic_quotes_runtime', 0);
+ini_set('magic_quotes_sybase', 0);
+ini_set('session.auto_start', 0);
ini_set('session.cache_expire', 200000);
ini_set('session.cache_limiter', 'none');
-ini_set('session.gc_maxlifetime', 200000);
ini_set('session.cookie_lifetime', 2000000);
+ini_set('session.gc_maxlifetime', 200000);
ini_set('session.save_handler', 'user');
ini_set('session.use_only_cookies', 1);
ini_set('session.use_trans_sid', 0);
+ini_set('track_vars', 1);
/**
* Variable overrides:
*
- * To override specific entries in the 'variable' table for this site,
- * set them here. You usually don't need to use this feature. This is
- * useful when used in a configuration file for a vhost or directory,
- * rather than the default settings.php. Any configuration setting from
- * the variable table can be given a new value.
+ * To override specific entries in the 'variable' table for this site,
+ * set them here. You usually don't need to use this feature. This is
+ * useful in a configuration file for a vhost or directory, rather than
+ * the default settings.php. Any configuration setting from the 'variable'
+ * table can be given a new value.
*/
-// $conf = array(
-// 'site_name' => 'My Drupal site',
-// 'theme_default' => 'pushbutton',
-// 'anonymous' => 'Visitor'
-// );
+//$conf = array(
+// 'site_name' => 'My Drupal site',
+// 'theme_default' => 'pushbutton',
+// 'anonymous' => 'Visitor'
+//);
?>
@@ -64,41 +63,47 @@ $db_prefix = '';
* PHP settings:
*
- * To see what PHP settings are known to work well, read the PHP
- * documentation at http://www.php.net/manual/en/ini.php#ini.list
- * and take a look at the .htaccess file to see which settings are
- * used there. Settings defined here should not be duplicated there
- * to avoid conflict issues.
+ * To see what PHP settings are possible, including whether they can
+ * be set at runtime (ie., when ini_set() occurs), read the PHP
+ * documentation at http://www.php.net/manual/en/ini.php#ini.list
+ * and take a look at the .htaccess file to see which non-runtime
+ * settings are used there.Settings defined here should not be
+ * duplicated there so as to avoid conflict issues.
*/